==> touhoulittlemaid-fabric-1.20.1-0.1.7.3-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemHakureiGohei.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IEnchantment;
import com.github.tartaricacid.touhoulittlemaid.advancements.maid.TriggerType;
import com.github.tartaricacid.touhoulittlemaid.api.block.IMultiBlock;
import com.github.tartaricacid.touhoulittlemaid.block.multiblock.MultiBlockManager;
import com.github.tartaricacid.touhoulittlemaid.init.InitTrigger;
import com.google.common.base.Predicates;
import com.google.common.collect.ImmutableMultimap;
import com.google.common.collect.Multimap;
import java.util.List;
import java.util.function.Predicate;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1799;
import net.minecraft.class_1811;
import net.minecraft.class_1838;
import net.minecraft.class_1839;
import net.minecraft.class_1887;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3499;
import net.minecraft.class_5134;

public class ItemHakureiGohei extends class_1811 implements IEnchantment {
    private final Multimap<class_1320, class_1322> defaultModifiers;

    public ItemHakureiGohei() {
        super((new class_1793()).method_7895(300)/*.setNoRepair()*/);
        ImmutableMultimap.Builder<class_1320, class_1322> builder = ImmutableMultimap.builder();
        builder.put(class_5134.field_23721, new class_1322(field_8006, "Tool modifier", 4, class_1322.class_1323.field_6328));
        builder.put(class_5134.field_23723, new class_1322(field_8001, "Tool modifier", -2, class_1322.class_1323.field_6328));
        this.defaultModifiers = builder.build();
    }

    public static boolean isGohei(class_1799 stack) {
        return stack.method_7909() instanceof ItemHakureiGohei;
    }

    @Override
    public Predicate<class_1799> method_19268() {
        return Predicates.alwaysTrue();
    }

    @Override
    public int method_24792() {
        return 15;
    }

    @Override
    public int method_7881(class_1799 stack) {
        return 500;
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8953;
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if (context.method_20287() == class_1268.field_5808) {
            List<IMultiBlock> multiBlockList = MultiBlockManager.getMultiBlockList();
            class_2680 blockState = context.method_8045().method_8320(context.method_8037());
            class_1937 world = context.method_8045();
            class_2338 pos = context.method_8037();
            class_2350 direction = context.method_8038();

            for (IMultiBlock multiBlock : multiBlockList) {
                if (multiBlock.isCoreBlock(blockState) && multiBlock.directionIsSuitable(direction)) {
                    if (world instanceof class_3218 serverLevel) {
                        class_2338 posStart = pos.method_10081(multiBlock.getCenterPos(direction));
                        class_3499 template = multiBlock.getTemplate(serverLevel, direction);
                        if (multiBlock.isMatch(world, posStart, direction, template)) {
                            multiBlock.build(world, posStart, direction, template);
                            serverLevel.method_8396(null, pos, class_3417.field_14703, class_3419.field_15245, 1.5f, 1);
                            if (context.method_8036() instanceof class_3222 serverPlayer) {
                                InitTrigger.MAID_EVENT.trigger(serverPlayer, TriggerType.BUILD_ALTAR);
                            }
                        }
                    }
                    return class_1269.field_5812;
                }
            }
        }
        return super.method_7884(context);
    }

    @Override
    public boolean method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        stack.method_7956(2, attacker, e -> e.method_20235(class_1304.field_6173));
        return true;
    }

    @Override
    public boolean canApplyAtEnchantingTable(class_1799 stack, class_1887 enchantment) {
        return enchantment == class_1893.field_9098
                || enchantment == class_1893.field_9108
                || IEnchantment.super.canApplyAtEnchantingTable(stack, enchantment);
    }

    @Override
    public Multimap<class_1320, class_1322> method_7844(class_1304 equipmentSlot) {
        return equipmentSlot == class_1304.field_6173 ? this.defaultModifiers : super.method_7844(equipmentSlot);
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.2-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemHakureiGohei.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IEnchantment;
import com.github.tartaricacid.touhoulittlemaid.advancements.maid.TriggerType;
import com.github.tartaricacid.touhoulittlemaid.api.block.IMultiBlock;
import com.github.tartaricacid.touhoulittlemaid.block.multiblock.MultiBlockManager;
import com.github.tartaricacid.touhoulittlemaid.init.InitTrigger;
import com.google.common.base.Predicates;
import com.google.common.collect.ImmutableMultimap;
import com.google.common.collect.Multimap;
import java.util.List;
import java.util.function.Predicate;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1320;
import net.minecraft.class_1322;
import net.minecraft.class_1799;
import net.minecraft.class_1811;
import net.minecraft.class_1838;
import net.minecraft.class_1839;
import net.minecraft.class_1887;
import net.minecraft.class_1893;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3499;
import net.minecraft.class_5134;

public class ItemHakureiGohei extends class_1811 implements IEnchantment {
    private final Multimap<class_1320, class_1322> defaultModifiers;

    public ItemHakureiGohei() {
        super((new class_1793()).method_7895(300)/*.setNoRepair()*/);
        ImmutableMultimap.Builder<class_1320, class_1322> builder = ImmutableMultimap.builder();
        builder.put(class_5134.field_23721, new class_1322(field_8006, "Tool modifier", 4, class_1322.class_1323.field_6328));
        builder.put(class_5134.field_23723, new class_1322(field_8001, "Tool modifier", -2, class_1322.class_1323.field_6328));
        this.defaultModifiers = builder.build();
    }

    public static boolean isGohei(class_1799 stack) {
        return stack.method_7909() instanceof ItemHakureiGohei;
    }

    @Override
    public Predicate<class_1799> method_19268() {
        return Predicates.alwaysTrue();
    }

    @Override
    public int method_24792() {
        return 15;
    }

    @Override
    public int method_7881(class_1799 stack) {
        return 500;
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8953;
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if (context.method_20287() == class_1268.field_5808) {
            List<IMultiBlock> multiBlockList = MultiBlockManager.getMultiBlockList();
            class_2680 blockState = context.method_8045().method_8320(context.method_8037());
            class_1937 world = context.method_8045();
            class_2338 pos = context.method_8037();
            class_2350 direction = context.method_8038();

            for (IMultiBlock multiBlock : multiBlockList) {
                if (multiBlock.isCoreBlock(blockState) && multiBlock.directionIsSuitable(direction)) {
                    if (world instanceof class_3218 serverLevel) {
                        class_2338 posStart = pos.method_10081(multiBlock.getCenterPos(direction));
                        class_3499 template = multiBlock.getTemplate(serverLevel, direction);
                        if (multiBlock.isMatch(world, posStart, direction, template)) {
                            multiBlock.build(world, posStart, direction, template);
                            serverLevel.method_8396(null, pos, class_3417.field_14703, class_3419.field_15245, 1.5f, 1);
                            if (context.method_8036() instanceof class_3222 serverPlayer) {
                                InitTrigger.MAID_EVENT.trigger(serverPlayer, TriggerType.BUILD_ALTAR);
                            }
                        }
                    }
                    return class_1269.field_5812;
                }
            }
        }
        return super.method_7884(context);
    }

    @Override
    public boolean method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        stack.method_7956(2, attacker, e -> e.method_20235(class_1304.field_6173));
        return true;
    }

    @Override
    public boolean tlm$canApplyAtEnchantingTable(class_1799 stack, class_1887 enchantment) {
        return enchantment == class_1893.field_9098
                || enchantment == class_1893.field_9108
                || IEnchantment.super.tlm$canApplyAtEnchantingTable(stack, enchantment);
    }

    @Override
    public Multimap<class_1320, class_1322> method_7844(class_1304 equipmentSlot) {
        return equipmentSlot == class_1304.field_6173 ? this.defaultModifiers : super.method_7844(equipmentSlot);
    }
}
